@@ -616,6 +616,31 @@ impl VisitMut for Normalizer {
     }
 }
 
+/// Converts `foo#1` to `foo__1` so it can be verified by the test.
+pub struct HygieneTester;
+impl Fold for HygieneTester {
+    fn fold_ident(&mut self, ident: Ident) -> Ident {
+        Ident {
+            sym: format!("{}__{}", ident.sym, ident.span.ctxt.as_u32()).into(),
+            ..ident
+        }
+    }
+
+    fn fold_member_prop(&mut self, p: MemberProp) -> MemberProp {
+        match p {
+            MemberProp::Computed(..) => p.fold_children_with(self),
+            _ => p,
+        }
+    }
+
+    fn fold_prop_name(&mut self, p: PropName) -> PropName {
+        match p {
+            PropName::Computed(..) => p.fold_children_with(self),
+            _ => p,
+        }
+    }
+}
+
 pub struct HygieneVisualizer;
 impl Fold for HygieneVisualizer {
     fn fold_ident(&mut self, ident: Ident) -> Ident {
